@@ -90,7 +90,7 @@ None by default.
 
 package Geo::OGC::Service;
 
-use 5.010000; # // and //=
+use 5.010000; # say // and //=
 use Modern::Perl;
 use Encode qw(decode encode);
 use Plack::Request;
@@ -104,7 +104,7 @@ use parent qw/Plack::Component/;
 
 binmode STDERR, ":utf8"; 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =pod
 
@@ -281,7 +281,7 @@ sub service {
         $names{lc($key)} = $key;
     }
 
-    my $self = { config => clone($config) };
+    my $self = {};
     for my $key (qw/SCRIPT_NAME PATH_INFO SERVER_NAME SERVER_PORT SERVER_PROTOCOL CONTENT_LENGTH CONTENT_TYPE
                     psgi.version psgi.url_scheme psgi.multithread psgi.multiprocess psgi.run_once psgi.nonblocking psgi.streaming/) {
         $self->{env}{$key} = $env->{$key};
@@ -338,6 +338,13 @@ sub service {
     my $service = $self->{parameters}{service} // $service_from_posted->($self->{posted}) // ''; 
 
     if (exists $services->{$service}) {
+        $self->{config} = get_config($config, $service);
+        unless ($self->{config}) {
+            error($responder, { exceptionCode => 'InvalidParameterValue',
+                                locator => 'service',
+                                ExceptionText => "'$service' is not configured in this server" } );
+            return undef;
+        }
         return bless $self, $services->{$service};
     }
 
@@ -347,6 +354,20 @@ sub service {
     return undef;
 }
 
+sub get_config {
+    my ($config, $service) = @_;
+    if (exists $config->{$service}) {
+        if (ref $config->{$service}) {
+            return $config->{$service};
+        }
+        if (ref $config->{$config->{$service}}) {
+            return $config->{$config->{$service}};
+        }
+        return undef;
+    }
+    return $config;
+}
+
 sub error {
     my ($responder, $msg) = @_;
     my $writer = Geo::OGC::Service::XMLWriter::Caching->new('text/xml');
